==> igniteui-angular-charts-16.0.0.tgz: package/esm2015/lib/Stacked100BarSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StackedBarSeries } from "./StackedBarSeries";
import { IStacked100Series_$type } from "./IStacked100Series";
import { Defaults } from "./Defaults";
import { markType } from "igniteui-angular-core";
import { Stacked100DataPreparer } from "./Stacked100DataPreparer";
import { isNaN_ } from "igniteui-angular-core";
import { StackedBarSeriesView } from "./StackedBarSeriesView";
import { Stacked100BarBucketCalculator } from "./Stacked100BarBucketCalculator";
/**
 * @hidden
 */
export let Stacked100BarSeries = /*@__PURE__*/ (() => {
    class Stacked100BarSeries extends StackedBarSeries {
        constructor() {
            super();
            this.ab = Stacked100BarSeries.$;
        }
        get_tt() {
            return true;
        }
        gw() {
            if (!isNaN_(this.gv)) {
                return super.gw();
            }
            return Defaults.h;
        }
        ac() {
            super.ac();
            this.ml(false);
        }
        bx() {
            return new Stacked100BarSeriesView(this);
        }
        l2(a) {
            super.l2(a);
            this.ux = a;
        }
        tl() {
            return this.ux;
        }
        t9() {
            super.t9();
            Stacked100DataPreparer.a(this);
        }
        get useHighMarkerFidelity() {
            return this.so;
        }
    }
    Stacked100BarSeries.$t = markType(Stacked100BarSeries, 'Stacked100BarSeries', StackedBarSeries.$, [IStacked100Series_$type]);
    return Stacked100BarSeries;
})();
/**
 * @hidden
 */
export let Stacked100BarSeriesView = /*@__PURE__*/ (() => {
    class Stacked100BarSeriesView extends StackedBarSeriesView {
        constructor(a) {
            super(a);
            this.c6 = null;
            this.c6 = a;
        }
        cs() {
            return new Stacked100BarBucketCalculator(this);
        }
        as() {
            super.as();
            if (!this.q) {
                this.c0.qh = Defaults.c;
                this.c0.g1 = Defaults.i;
            }
        }
    }
    Stacked100BarSeriesView.$t = markType(Stacked100BarSeriesView, 'Stacked100BarSeriesView', StackedBarSeriesView.$);
    return Stacked100BarSeriesView;
})();

==> igniteui-angular-charts-17.2.1.tgz: package/esm2015/lib/Stacked100BarSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StackedBarSeries } from "./StackedBarSeries";
import { IStacked100Series_$type } from "./IStacked100Series";
import { Defaults } from "./Defaults";
import { markType } from "igniteui-angular-core";
import { Stacked100DataPreparer } from "./Stacked100DataPreparer";
import { isNaN_ } from "igniteui-angular-core";
import { StackedBarSeriesView } from "./StackedBarSeriesView";
import { Stacked100BarBucketCalculator } from "./Stacked100BarBucketCalculator";
/**
 * @hidden
 */
export let Stacked100BarSeries = /*@__PURE__*/ (() => {
    class Stacked100BarSeries extends StackedBarSeries {
        constructor() {
            super();
            this.ab = Stacked100BarSeries.$;
        }
        get_xo() {
            return true;
        }
        iq() {
            if (!isNaN_(this.ip)) {
                return super.iq();
            }
            return Defaults.h;
        }
        ac() {
            super.ac();
            this.pq(false);
        }
        ch() {
            return new Stacked100BarSeriesView(this);
        }
        o1(a) {
            super.o1(a);
            this.ys = a;
        }
        xg() {
            return this.ys;
        }
        x4() {
            super.x4();
            Stacked100DataPreparer.a(this);
        }
        get useHighMarkerFidelity() {
            return this.wj;
        }
    }
    Stacked100BarSeries.$t = markType(Stacked100BarSeries, 'Stacked100BarSeries', StackedBarSeries.$, [IStacked100Series_$type]);
    return Stacked100BarSeries;
})();
/**
 * @hidden
 */
export let Stacked100BarSeriesView = /*@__PURE__*/ (() => {
    class Stacked100BarSeriesView extends StackedBarSeriesView {
        constructor(a) {
            super(a);
            this.c9 = null;
            this.c9 = a;
        }
        cv() {
            return new Stacked100BarBucketCalculator(this);
        }
        au() {
            super.au();
            if (!this.q) {
                this.c3.ub = Defaults.c;
                this.c3.iv = Defaults.i;
            }
        }
    }
    Stacked100BarSeriesView.$t = markType(Stacked100BarSeriesView, 'Stacked100BarSeriesView', StackedBarSeriesView.$);
    return Stacked100BarSeriesView;
})();
